@@ -1,4 +1,4 @@
-// SPDX-FileCopyrightText: 2011 - 2023 UnionTech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2011 - 2022 UnionTech Software Technology Co., Ltd.
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -25,11 +25,21 @@ void DBusShutdownFrontService::Shutdown()
     parent()->Shutdown();
 }
 
+void DBusShutdownFrontService::UpdateAndShutdown()
+{
+    parent()->UpdateAndShutdown();
+}
+
 void DBusShutdownFrontService::Restart()
 {
     parent()->Restart();
 }
 
+void DBusShutdownFrontService::UpdateAndReboot()
+{
+    parent()->UpdateAndReboot();
+}
+
 void DBusShutdownFrontService::Logout()
 {
     parent()->Logout();
@@ -54,3 +64,8 @@ void DBusShutdownFrontService::Lock()
 {
     parent()->Lock();
 }
+
+bool DBusShutdownFrontService::visible() const
+{
+    return parent()->Visible();
+}
