@@ -56,11 +56,6 @@ void setPointer();
  */
 bool isDeepinAuth();
 
-/**
- * @brief 把字符串解析成时间，然后转换为Unix时间戳
- */
-uint timeFromString(QString time);
-
 /**
  * @brief 设置app类型，让程序知道应该获取哪个配置文件
  */
@@ -87,4 +82,10 @@ void configWebEngine();
 bool isSleepLock();
 #endif
 
+/**
+ * @brief convert 'some-key' to 'someKey'.
+ */
+
+QString qtifyName(const QString &name);
+
 #endif // PUBLIC_FUNC_H
