@@ -61,6 +61,7 @@ signals:
     void requestLockFrameHide();
     void parentChanged();
     void noPasswordLoginChanged(const QString &account, bool noPassword);
+    void requestLockStateChange(const bool locked);
 
 public slots:
     void pushPasswordFrame();
@@ -101,8 +102,6 @@ protected:
     void initFMAWidget();
     void initUserListWidget();
     void enableSystemShortcut(const QStringList &shortcuts, bool enabled, bool isPersistent);
-    QString getCurrentKBLayout() const;
-    void setKBLayout(const QString &layout);
 
 protected:
     SessionBaseModel *m_model = nullptr;
@@ -135,8 +134,6 @@ protected:
     bool m_MPRISEnable = false;
     bool m_showMediaWidget = false;
     bool m_hasResetPasswordDialog = false;
-
-    QString m_originalKBLayout;
 };
 
 #endif // LOCKCONTENT_H
