@@ -1,4 +1,4 @@
-// SPDX-FileCopyrightText: 2023 UnionTech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -15,7 +15,7 @@ protected:
     void SetUp() override;
     void TearDown() override;
 
-    FullscreenBackground *m_background;
+    FullScreenBackground *m_background;
     SessionBaseModel *m_model;
 };
 
@@ -24,7 +24,7 @@ void UT_FullscreenBackground::SetUp()
     m_model = new SessionBaseModel();
     std::shared_ptr<User> user_ptr(new User);
     m_model->updateCurrentUser(user_ptr);
-    m_background = new FullscreenBackground(m_model);
+    m_background = new FullScreenBackground(m_model);
 }
 
 void UT_FullscreenBackground::TearDown()
@@ -39,7 +39,6 @@ TEST_F(UT_FullscreenBackground, BasicTest)
     m_background->setContent(&w);
     m_background->isPicture("/usr/share/backgrounds/default_background.jpg");
     m_background->getLocalFile("/usr/share/backgrounds/default_background.jpg");
-    m_background->setContentVisible(true);
     m_background->contentVisible();
     m_background->setEnterEnable(true);
     m_background->updateBackground("/usr/share/backgrounds/default_background.jpg");
